@@ -1163,7 +1163,7 @@ def get_config(
     for service in config["services"].values():
         image = service["image"]
         br = parse_complete_tag(image)
-        br.digest = None
+        # br.tag = None
         service["image"] = get_complete_tag(br)
         #
         # if do_trick:
